@@ -1,6 +1,6 @@
 /***************************************************************************
-** $Id: configdialog.cpp,v 1.49 2008/03/25 20:14:02 hoganrobert Exp $
-*   Copyright (C) 2006 by Robert Hogan                                    *
+** $Id: configdialog.cpp,v 1.51 2008/07/31 19:56:25 hoganrobert Exp $
+*   Copyright (C) 2006 - 2008 Robert Hogan                                *
 *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -49,7 +49,7 @@ email                : markey@web.de
 #include "portsandnames.h"
 #include "tork.h"
 #include "crypto.h"
-#include "config.h"
+#include "../config.h"
 
 #include <qcombobox.h>
 #include <qgroupbox.h>
@@ -101,7 +101,10 @@ TorkConfigDialog::TorkConfigDialog( QWidget *parent, const char* name, KConfigSk
 
     // add pages
     addPage( m_quickconfig, i18n( "Quick Configure" ), "cache", i18n( "Quick Configuration" ) );
+#ifndef LIVECD
     addPage( m_konq, i18n( "Konqueror" ), "tork_konqueror_play", i18n( "Konqueror and Privacy Proxy" ) );
+#endif
+
 #ifndef LIVECD
     addPage( m_running, i18n( "My Tor Client" ), "launch", i18n( "Configure My Client" ) );
 #endif
@@ -120,17 +123,15 @@ TorkConfigDialog::TorkConfigDialog( QWidget *parent, const char* name, KConfigSk
         addPage( m_torservers, i18n( "My Network View" ), "network", 
                  i18n( "Configure My Network View" ) );
     }
-#ifndef LIVECD
     if (!TorkConfig::clientOnly()){
         addPage( m_myserver, i18n( "My Tor Server" ), "system", i18n( "Configure My Server" ) );
         addPage( m_maxmin, i18n( "My Server Bandwidth" ), "filter", i18n( "Configure My Bandwidth" ) );
     }
-
     if (!TorkConfig::hiddenServices().isEmpty())
         addPage( m_myhidden, i18n( "My Hidden Services" ), "tork_agent", 
                          i18n( "Configure My Hidden Services" ) );
     
-#endif
+
     QObjectList *list = queryList( "QLabel", "infoPixmap" );
     for( QObject *label = list->first(); label; label = list->next() )
         static_cast<QLabel*>(label)->setPixmap( QMessageBox::standardIcon( QMessageBox::Information ) );
