@@ -1,6 +1,6 @@
 /***************************************************************************
- * $Id: newstreamosd.cpp,v 1.20 2008/06/02 10:38:26 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan                                    *
+ * $Id: newstreamosd.cpp,v 1.22 2008/08/20 16:49:22 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,7 +32,7 @@
  * See the file "COPYING" for the exact licensing terms.
  *
  * Some minor changes for TorK:
- *   Copyright (C) 2006 by Robert Hogan                                    *
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
  */
@@ -63,13 +63,14 @@
 #include <qtooltip.h> //QToolTip::palette()
 
 
-StreamOSD::StreamOSD( torkView* parent, const char* name )
+StreamOSD::StreamOSD( torkView* parent, bool tortraffic, const char* name )
   : QWidget( parent, name, WType_TopLevel | WNoAutoErase | WStyle_Customize | WX11BypassWM | WStyle_StaysOnTop ),
     m_dirty(true),
     m_dragging(false),
     m_screen(0),
     m_position(s_outerMargin, s_outerMargin),
-    m_parent(parent)
+    m_parent(parent),
+    m_tortraffic(tortraffic)
 {
   setFocusPolicy( NoFocus );
   setBackgroundMode( NoBackground );
@@ -78,7 +79,11 @@ StreamOSD::StreamOSD( torkView* parent, const char* name )
 
   // make sure we are always visible
   KWin::setOnAllDesktops( winId(), true );
-  renderOSD();
+
+  if (m_tortraffic)
+    renderOSD();
+  else
+    renderNonTorOSD();
 
 }
 
@@ -118,30 +123,18 @@ void StreamOSD::setPosition( const QPoint& p )
 
 void StreamOSD::refresh()
 {
-  if( isVisible() )
-    renderOSD();
-  else
+  if( isVisible() ){
+    if (m_tortraffic)
+      renderOSD();
+    else
+      renderNonTorOSD();
+  }else
     m_dirty = true;
 }
 
 
 void StreamOSD::renderOSD()
 {
-  // ----------------------------------------
-  // |        Copying CD                    |
-  // |  K3B   ========== 40%                |
-  // |                                      |
-  // ----------------------------------------
-
-/*    QFrame* frame = new QFrame(this);
-    frame->setFrameStyle( QFrame::Panel | QFrame::Raised );
-    frame->setFrameShape( QFrame::StyledPanel );*/
-    //6 10
-    //8 10
-    //kdDebug() << fontMetrics().width( 'x' ) << endl;
-    //kdDebug() << font().pointSize() << endl;
-
-    //QColor osdcolor = QColor(200,208,203,QColor::Rgb);
     QColor osdcolor = QToolTip::palette().color(QPalette::Active, QColorGroup::Background);
     int large = font().pointSize();
     int small = font().pointSize() - 1;
@@ -265,6 +258,90 @@ void StreamOSD::renderOSD()
 
 }
 
+void StreamOSD::renderNonTorOSD()
+{
+    QColor osdcolor = Qt::green;
+    int large = font().pointSize();
+    int small = font().pointSize() - 1;
+    QFont f( font().rawName(), small );
+    setFont( f );
+    setWFlags( Qt::WX11BypassWM );
+    setPalette(osdcolor);
+    setPaletteBackgroundColor(osdcolor);
+    //setBackgroundMode( PaletteBase );
+    QGridLayout* TabPageLayout = new QGridLayout( this, 3, 8, 11, 6, "TabPageLayout"); 
+    TabPageLayout->setMargin(2);
+    QLabel* textLabel = new QLabel( this, "textLabel2" );
+    textLabel->setText(i18n("<b>Tor Traffic</b>"));
+    QFont f2( font().rawName(), large  );
+    textLabel->setFont( f2 );
+
+    TabPageLayout->addMultiCellWidget( textLabel, 0,0,0,3 );
+
+    QToolButton* hideMonitor = new QToolButton( this,"hide" );
+    hideMonitor->setIconSet( SmallIconSet( "cancel" ) );
+    hideMonitor->setUsesTextLabel(false);
+    hideMonitor->setMaximumSize(SmallIconSet( "cancel" ).iconSize(QIconSet::Small));
+    hideMonitor->adjustSize();
+    TabPageLayout->addWidget(hideMonitor,0,7);
+    QToolTip::add( hideMonitor,i18n("Hide this Display."));
+
+    QToolTip::add( this,i18n("This displays all your system's network activity."));
+
+     connect( hideMonitor, SIGNAL(clicked()),
+         SLOT(slotHideMonitor()) );
+
+
+    infoList = new QListView( this, "infoList" );
+    infoList->addColumn(  "Program"  );
+    infoList->addColumn(  "Host"  );
+    infoList->addColumn(  "KB/s"  );
+    infoList->setColumnWidthMode(0, QListView::Manual);
+    infoList->header()->setResizeEnabled(FALSE, 0);
+    infoList->setResizeMode( QListView::NoColumn );
+    infoList->setHScrollBarMode(QScrollView::AlwaysOff);
+    infoList->setVScrollBarMode(QScrollView::AlwaysOff);
+    infoList->setSelectionMode( QListView::Single );
+    TabPageLayout->addMultiCellWidget( infoList, 1,1,0,7 );
+    infoList->setPaletteBackgroundColor(osdcolor);
+
+	m_graphOut = new StatGraph(this,1,0,"Up");
+	m_graphIn = new StatGraph(this,1,0,"Down");
+    m_graphOut->setReadingColor(Qt::red);
+    m_graphIn->setReadingColor(Qt::green);
+    TabPageLayout->addMultiCellWidget( m_graphOut, 2,2, 0,3 );
+    TabPageLayout->addMultiCellWidget( m_graphIn, 2, 2, 4,7 );
+
+    QPoint point;
+    QRect rect( point, size() );
+    const uint M = fontMetrics().width( 'x' );
+
+
+    const uint xround = (M * 200) / size().width();
+    const uint yround = (M * 200) / size().height();
+
+
+    {   /// apply the mask
+        static QBitmap mask;
+
+        mask.resize( size() );
+        mask.fill( Qt::black );
+
+        QPainter p( &mask );
+        p.setBrush( Qt::white );
+        p.drawRoundRect( rect, xround, yround );
+        setMask( mask );
+    }
+
+      m_osdBuffer.resize( rect.size() );
+      QPainter p( &m_osdBuffer );
+      p.fillRect( rect, backgroundColor() );
+      p.setPen( backgroundColor().dark() );
+      p.drawRoundRect( rect, xround, yround );
+      p.end();
+
+}
+
 
 void StreamOSD::setScreen( int screen )
 {
@@ -391,7 +468,10 @@ QPoint StreamOSD::fixupPosition( const QPoint& pp )
 void StreamOSD::readSettings( KConfigBase* c )
 {
   QString oldGroup = c->group();
-  c->setGroup( "TorKOSD Position" );
+  if (m_tortraffic)
+    c->setGroup( "TorKOSD Position" );
+  else
+    c->setGroup( "NonTorOSD Position" );
 
   setPosition( c->readPointEntry( "Position", 0 ) );
   setScreen( c->readNumEntry( "Screen", 0 ) );
@@ -403,7 +483,10 @@ void StreamOSD::readSettings( KConfigBase* c )
 void StreamOSD::saveSettings( KConfigBase* c )
 {
   QString oldGroup = c->group();
-  c->setGroup( "TorKOSD Position" );
+  if (m_tortraffic)
+    c->setGroup( "TorKOSD Position" );
+  else
+    c->setGroup( "NonTorOSD Position" );
 
   c->writeEntry( "Position", m_position );
   c->writeEntry( "Screen", m_screen );
