@@ -1,5 +1,5 @@
 /***************************************************************************
- ** $Id: torkview.cpp,v 1.123 2008/12/08 19:49:28 hoganrobert Exp $
+ ** $Id: torkview.cpp,v 1.125 2009/11/07 14:21:56 hoganrobert Exp $
  *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
@@ -112,14 +112,14 @@ torkView::torkView(QWidget *parent)
     circuitIconList << greenonion << redonion << yellowonion << littleonion;
 
 
-    torType += "running a Tor Client and Server With Default Settings";
-    torType += "running a Tor Client and Relay Server With Default Settings";
-    torType +=  "running a Tor Server With Default Settings";
-    torType +=  "running a Tor Relay Server With Default Settings";
-    torType +=  "running a Tor Client with Default Settings";
-    torType +=  "running an instance of Tor using all the settings in the configure dialog";
-    torType +=  "connected to a Remote Instance of Tor";
-    torType +=  "connected to a Local Instance of Tor";
+    torType += i18n("running a Tor Client and Server With Default Settings");
+    torType += i18n("running a Tor Client and Relay Server With Default Settings");
+    torType += i18n("running a Tor Server With Default Settings");
+    torType += i18n("running a Tor Relay Server With Default Settings");
+    torType += i18n("running a Tor Client with Default Settings");
+    torType += i18n("running an instance of Tor using all the settings in the configure dialog");
+    torType += i18n("connected to a Remote Instance of Tor");
+    torType += i18n("connected to a Local Instance of Tor");
 
     streamPurpose["DIR_FETCH"] = "Tor(Directory Fetch)";
     streamPurpose["DNS_REQUEST"] = "Tor(DNS)";
@@ -295,7 +295,7 @@ bool torkView::checkInterface() {
 void torkView::torify(const QString& text)
 {
 
-    QString command = "torkify " + text;
+    QString command = "usewithtor " + text;
     QString icon = text.section(" ",0,0);
     KRun::runCommand( command, icon, icon );
 
