@@ -1,5 +1,5 @@
 /***************************************************************************
- ** $Id: torkview.h,v 1.58 2008/12/25 11:57:27 hoganrobert Exp $
+ ** $Id: torkview.h,v 1.59 2009/10/20 20:16:00 hoganrobert Exp $
  *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
@@ -135,7 +135,7 @@ public:
 
 	const double* speedHistoryRx() const { return mSpeedHistoryRx; }
 	const double* speedHistoryTx() const { return mSpeedHistoryTx; }
-	const int historyBufferSize() const { return HISTORY_SIZE; }
+	int historyBufferSize() const { return HISTORY_SIZE; }
 	const int* historyPointer() const { return &mSpeedHistoryPtr; }
 	const double* maxSpeed() const { return &mMaxSpeed; }
 
@@ -143,7 +143,7 @@ public:
                   const { return sys_mSpeedHistoryRx; }
 	const double* sys_speedHistoryTx()
                   const { return sys_mSpeedHistoryTx; }
-	const int sys_historyBufferSize() const { return HISTORY_SIZE; }
+	int sys_historyBufferSize() const { return HISTORY_SIZE; }
 	const int* sys_historyPointer()
                   const { return &sys_mSpeedHistoryPtr; }
 	const double* sys_maxSpeed() const { return &sys_mMaxSpeed; }
@@ -411,7 +411,7 @@ public:
 
 	const double* speedHistoryRx() const { return mSpeedHistoryRx; }
 	const double* speedHistoryTx() const { return mSpeedHistoryTx; }
-	const int historyBufferSize() const { return HISTORY_SIZE; }
+	int historyBufferSize() const { return HISTORY_SIZE; }
 	const int* historyPointer() const { return &mSpeedHistoryPtr; }
 	const double* maxSpeed() const { return &mMaxSpeed; }
 
