@@ -1,5 +1,5 @@
 /***************************************************************************
- * $Id: torkview_base.ui.h,v 1.47 2008/07/31 19:56:28 hoganrobert Exp $
+ * $Id: torkview_base.ui.h,v 1.48 2009/06/20 09:29:15 hoganrobert Exp $
  *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
@@ -78,12 +78,12 @@ void torkview_base::init()
     serverList->setHScrollBarMode(QScrollView::AlwaysOff);
 
     streamList->addColumn( "ID" );
-    streamList->addColumn(  "Source"  );
-    streamList->addColumn(  "Host/Port"  );
+    streamList->addColumn(  tr2i18n("Source")  );
+    streamList->addColumn(  tr2i18n("Host/Port")  );
     streamList->addColumn(  kapp->iconLoader()->loadIconSet("tork_torsmall", KIcon::Small),"", 24  );
-    streamList->addColumn(  "Speed"  );
-    streamList->addColumn(  "Exit"  );
-    streamList->addColumn(  "Circuit"  );
+    streamList->addColumn(  tr2i18n("Speed")  );
+    streamList->addColumn(  tr2i18n("Exit")  );
+    streamList->addColumn(  tr2i18n("Circuit")  );
 
     streamList->setSelectionMode( QListView::Extended );
     streamList->setColumnWidthMode(0, QListView::Manual);
