@@ -1,6 +1,6 @@
 /***************************************************************************
- * $Id: trayicon.cpp,v 1.8 2008/06/08 21:05:12 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan                                    *
+ * $Id: trayicon.cpp,v 1.10 2008/07/31 19:56:28 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,7 +20,7 @@
  ***************************************************************************
  * This is a modified version of trayicon.cpp from ktorrent.               *
  * Original copyright notice follows:                                      *
-/***************************************************************************
+ ***************************************************************************
  *   Copyright (C) 2005 by                                                 *
  *   Joris Guisson <joris.guisson@gmail.com>                               *
  *   Ivan Vasic <ivasic@gmail.com>                                         *
@@ -42,6 +42,8 @@
  ***************************************************************************/
 
 #include <kpopupmenu.h>
+#include <kurldrag.h>
+#include <kdebug.h>
 #include <klocale.h>
 #include <kapplication.h>
 #include "trayicon.h"
@@ -52,14 +54,16 @@
 #include "torkconfig.h"
 
 
-TrayIcon::TrayIcon( QWidget *parent, const char *name)
+TrayIcon::TrayIcon( tork *parent, const char *name)
 		: KSystemTray(parent, name)
 {
 	m_kt_pix = loadIcon("tork");
 	setPixmap(m_kt_pix);
 	paint=new QPainter( this );
 	drawContents ( paint );
-	
+	m_parent = parent;
+
+    setAcceptDrops( TRUE );
 	m_hover_popup = new TrayHoverPopup(m_kt_pix,this);
 
 	connect(this,SIGNAL(quitSelected()),kapp,SLOT(quit()));
@@ -71,6 +75,29 @@ TrayIcon::TrayIcon( QWidget *parent, const char *name)
 TrayIcon::~TrayIcon()
 {}
 
+void  TrayIcon::dragEnterEvent(QDragEnterEvent *e)
+{
+    e->accept (KURLDrag::canDecode(e));
+}
+
+void  TrayIcon::dropEvent (QDropEvent *o)
+{
+    KURL::List list;
+    QString text;
+    if ( KURLDrag::decode( o, list ) )
+            droppedfile(list);
+}
+
+void  TrayIcon::droppedfile (KURL::List url)
+{
+    m_parent->startEverything();
+    if (TorkConfig::availablePrograms().contains("konqueror"))
+      m_parent->enableKDEAndLaunchKonqWithUrl(url.first().url());
+    else if (TorkConfig::availablePrograms().contains("firefox"))
+      m_parent->anonymizedFirefox(url.first().url());
+}
+
+
 void TrayIcon::enterEvent(QEvent* ev)
 {
 	KSystemTray::enterEvent(ev);
