@@ -1,6 +1,6 @@
 /***************************************************************************
- * $Id: trayicon.h,v 1.5 2008/06/08 21:05:12 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan                                    *
+ * $Id: trayicon.h,v 1.7 2008/07/31 19:56:28 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -45,6 +45,7 @@
 #include <ksystemtray.h>
 #include <kpopupmenu.h>
 #include <qpainter.h>
+#include <kurl.h>
 #include <tork.h>
 
 
@@ -60,7 +61,7 @@ class TrayIcon : public KSystemTray
 {
 	Q_OBJECT
 public:
-	TrayIcon(QWidget *parent = 0, const char *name = 0);
+	TrayIcon(tork *parent = 0, const char *name = 0);
 	virtual ~TrayIcon();
 
 	/// Update stats for system tray icon
@@ -71,12 +72,15 @@ public:
 private:
 	virtual void enterEvent(QEvent* ev);
 	virtual void leaveEvent(QEvent* ev);
-
-	
+    virtual void dragEnterEvent(QDragEnterEvent *e);
+    virtual void dropEvent (QDropEvent *o);
+	void droppedfile (KURL::List url);
 private:
 	QPainter *paint;
 	TrayHoverPopup* m_hover_popup;
 	QPixmap m_kt_pix;
+    tork *m_parent;
+
 };
 
 
