@@ -1,5 +1,5 @@
 /***************************************************************************
- * $Id: warnings.h,v 1.33 2008/07/31 19:56:28 hoganrobert Exp $
+ * $Id: warnings.h,v 1.34 2009/06/20 09:29:15 hoganrobert Exp $
  *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
@@ -185,7 +185,7 @@ static message_t _tork_messages[] = {
     MSG("your DirPort is reachable from the outside", 
         i18n("Your Tor Server's directory appears to be working!!"),
         "",
-        "You can now serve directory listings to the Tor network. Be careful out there!",
+        i18n("You can now serve directory listings to the Tor network. Be careful out there!"),
         i18n("Show Usage Warnings"),
         "tork_torserver",
         (&tork::showUsage),
